//importing functions and objects from D3 library
import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

// svg element and storing values in width and height variables
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');


// numberformat function is to deine $ in gas price
const numberFormat = number =>
  	(Math.abs(Number(number))) + " $" ;

// render function takes the array of gas prices data of various countries and 
//creates pie chart using pie and arc functions from D3 and shows top 10 countries and their gas prices
const render = data => {
  const pieData = pie().sort(null).value(d=>d.Price_Per_Gallon)(data);
  const colors = scaleOrdinal(schemeCategory10);
    
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
    const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.Price_Per_Gallon))
    .on("mouseover", d => console.log(d.data.Price_Per_Gallon));

  
  //piechart is created with legends for the chart
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // list of each country as labels and its styles 
  // dimensions for color legends
  legend.append("rect").attr("width",22).attr("height",15)
  	.attr("fill", d => colors(d.data.Price_Per_Gallon));
  // dimensions settings for countries name display
  legend.append("text")
  	.attr("x", 28)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  //dimension parameters for gas price display with $ symbol
  legend.append("text")
  	.attr("x", 260)
  	.attr("y", 20)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.Price_Per_Gallon));
}

// url of my dataset gist

const csvUrl =
 'https://gist.githubusercontent.com/yamunayennem/1245e235778fdce3d8b1a8ded2a3c408/raw/33e343f4ed6671c428780ada42f9b80b03127863/gasprice_june2023_dataset.csv';


//Load the data and display basic cost of netflix 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.Price_Per_Gallon-data1.Price_Per_Gallon);
    if (csvData) {
      render(csvData.slice(0,10)); // No. of countries being displayed
    }
});